package com.ruoyi.cs.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.cs.domain.vo.CsProjectClassVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.cs.mapper.CsProjectClassMapper;
import com.ruoyi.cs.domain.CsProjectClass;
import com.ruoyi.cs.service.ICsProjectClassService;

import javax.annotation.Resource;

/**
 * 项目类别Service业务层处理
 *
 * @author ruoyi
 * @date 2024-04-22
 */
@Service
public class CsProjectClassServiceImpl implements ICsProjectClassService
{
    @Resource
    private CsProjectClassMapper csProjectClassMapper;

    /**
     * 查询项目类别
     *
     * @param projectClassId 项目类别主键
     * @return 项目类别
     */
    @Override
    public CsProjectClass selectCsProjectClassByProjectClassId(String projectClassId)
    {
        return csProjectClassMapper.selectCsProjectClassByProjectClassId(projectClassId);
    }

    /**
     * 查询项目类别列表
     *
     * @param csProjectClass 项目类别
     * @return 项目类别
     */
    @Override
    public List<CsProjectClass> selectCsProjectClassList(CsProjectClass csProjectClass)
    {
        return csProjectClassMapper.selectCsProjectClassList(csProjectClass);
    }

    /**
     * 新增项目类别
     *
     * @param csProjectClass 项目类别
     * @return 结果
     */
    @Override
    public int insertCsProjectClass(CsProjectClass csProjectClass)
    {
        csProjectClass.setProjectClassId(IdUtils.fastSimpleUUID());
        csProjectClass.setCreateAt(DateUtils.getTime());
        csProjectClass.setDelFlag("0");
        return csProjectClassMapper.insertCsProjectClass(csProjectClass);
    }

    /**
     * 修改项目类别
     *
     * @param csProjectClass 项目类别
     * @return 结果
     */
    @Override
    public int updateCsProjectClass(CsProjectClass csProjectClass)
    {
        csProjectClass.setUpdateAt(DateUtils.getTime());
        return csProjectClassMapper.updateCsProjectClass(csProjectClass);
    }

    /**
     * 批量删除项目类别
     *
     * @param projectClassIds 需要删除的项目类别主键
     * @return 结果
     */
    @Override
    public int deleteCsProjectClassByProjectClassIds(String[] projectClassIds)
    {
        return csProjectClassMapper.deleteCsProjectClassByProjectClassIds(projectClassIds);
    }

    /**
     * 删除项目类别信息
     *
     * @param projectClassId 项目类别主键
     * @return 结果
     */
    @Override
    public int deleteCsProjectClassByProjectClassId(String projectClassId)
    {
        return csProjectClassMapper.deleteCsProjectClassByProjectClassId(projectClassId);
    }

    /**
     * 查询项目类别下拉列表
     *
     * @return 项目类别集合
     */
    @Override
    public List<CsProjectClassVO> selectCsProjectClassVOList() {
        return csProjectClassMapper.selectCsProjectClassVOList();
    }
}
